@@ -1,37 +1,41 @@
-#' @title Create a new dataset_df object
-#' @description The \code{dataset_df} constructor creates the objects of this
-#' class, which are semantically rich, modern data frames inherited from
-#' \code{\link[tibble:tibble]{tibble::tibble}}.
-#' @details To check if an object has the class dataset_df use
-#' \code{is.dataset_df}.\cr \cr \code{print} is the method to print out the
-#' semantically rich data frames created with the constructor of
-#' \code{dataset_df}.\cr \cr \code{summary} is the method to summarise these
-#' semantically rich data frames.\cr \cr
-#' For more details, please check the \code{vignette("dataset_df",
-#' package = "dataset")}
-#' vignette.
-#' @param identifier Defaults to \code{c(eg="http://example.com/dataset#")},
-#'   which should be changed to the permanent identifier of the dataset. For
-#'   example, if your dataset will be released with the Digital Object
-#'   Identifier (DOI) `https;//doi.org/1234`, you should use a short prefixed
-#'   identifier like \code{c(obs="https://doi.org/1234#")}, which will resolve
-#'   to the rows being identified as
-#'   https://doi.org/1234#1...https://doi.org/1234#n.
-#' @param dataset_bibentry A list of bibliographic references and descriptive
-#'   metadata about the dataset as a whole created with \code{\link{datacite}}
-#'   or \code{\link{dublincore}}.
-#' @param var_labels The long, human readable labels of each variable.
-#' @param units The units of measurement for the measured variables.
-#' @param concepts The linked concepts of the variables, attributes, or
-#'   constants.
-#' @param dataset_subject The subject of the dataset, see \code{\link{subject}}.
-#' @param ... The vectors (variables) that should be included in the dataset.
-#' @param x A \code{dataset_df} object for S3 methods.
-#' @param df A \code{data.frame} to be converted to \code{dataset_df}.
-#' @return \code{dataset_df} is the constructor of this type, it returns an
-#'   object inherited from a data frame with semantically rich metadata.
-#' @import vctrs
-#' @import pillar
+#' Create a new `dataset_df` object
+#'
+#' The `dataset_df()` constructor creates semantically rich modern data frames.
+#' These inherit from [`tibble::tibble`] and carry structured metadata using
+#' attributes.
+#'
+#' Use `is.dataset_df()` to check class membership.
+#'
+#' S3 methods for `dataset_df` include:
+#' - `print()` to display the dataset with metadata
+#' - `summary()` to summarize both data and metadata
+#'
+#' For full details, see `vignette("dataset_df", package = "dataset")`.
+#'
+#' @param ... Vectors (columns) that should be included in the dataset.
+#' @param identifier A named vector of one or more URI prefixes for row IDs.
+#'   Defaults to `c(eg = "http://example.com/dataset#")`. For example, if your
+#'   dataset will be published under DOI `https://doi.org/1234`, you may use
+#'   `c(obs = "https://doi.org/1234#")`, which will generate row URIs such as
+#'   `https://doi.org/1234#1`, ..., `#n`.
+#' @param dataset_bibentry A bibliographic metadata record for the dataset,
+#'   created using [`datacite()`] or [`dublincore()`].
+#' @param var_labels A named list of human-readable labels for each variable.
+#' @param units A named list of measurement units for measured variables.
+#' @param concepts A named list of linked concepts (URIs) for variables or
+#'   dimensions.
+#' @param dataset_subject A subject descriptor created with [`subject()`] or
+#'   [`subject_create()`].
+#' @param x A `dataset_df` object (used in method dispatch).
+#' @param df A `data.frame` to convert to a `dataset_df`.
+#'
+#' @return A `dataset_df` object: a tibble with attached metadata stored in
+#'   attributes.
+#'
+#' @note A simple, serverless scaffolding for publishing `dataset_df` objects
+#'   on the web (with HTML + RDF exports) is available at
+#'   <https://github.com/dataobservatory-eu/dataset-template>.
+#'
 #' @examples
 #' my_dataset <- dataset_df(
 #'   country_name = defined(
@@ -45,38 +49,44 @@
 #'     unit = "million dollars",
 #'     concept = "http://data.europa.eu/83i/aa/GDP"
 #'   ),
-#'   dataset_bibentry =  dublincore(
-#'     title = "GDP of Andorra And Lichtenstein",
-#'     description = "A small but semantically rich datset example.",
+#'   identifier = c(
+#'     obs = "https://dataobservatory-eu.github.io/dataset-template#"
+#'   ),
+#'   dataset_bibentry = dublincore(
+#'     title = "GDP of Andorra and Liechtenstein",
+#'     description = "A small but semantically rich dataset example.",
 #'     creator = person("Jane", "Doe", role = "cre"),
 #'     publisher = "Open Data Institute",
-#'     language = "en")
-#'  )
+#'     language = "en"
+#'   )
+#' )
 #'
-#' # Use standard methods, like print, summary, head, tail
+#' # Basic usage
 #' print(my_dataset)
 #' head(my_dataset)
-#' tail(my_dataset)
+#' summary(my_dataset)
 #'
-#' # Check class:
-#' is.dataset_df(my_dataset)
-#'
-#' # To check the bibliographic metadata of a dataset,
-#' # use as_dublincore for DCTERMS:
+#' # Metadata access
 #' as_dublincore(my_dataset)
-#'
-#' # ... and as_datacite for DataCite:
 #' as_datacite(my_dataset)
+#'
+#' # Export description as RDF triples
+#' my_description <- describe(my_dataset, con = tempfile())
+#' my_description
+#'
+#' @seealso [defined()], [dublincore()], [datacite()], [subject()]
+#'
 #' @export
 
 # User constructor
-dataset_df <- function(...,
-                       identifier = c(eg = "http://example.com/dataset#"),
-                       var_labels = NULL,
-                       units = NULL,
-                       concepts = NULL,
-                       dataset_bibentry = NULL,
-                       dataset_subject = NULL) {
+dataset_df <- function(
+    ...,
+    identifier = c(obs = "http://example.com/dataset#obs"),
+    var_labels = NULL,
+    units = NULL,
+    concepts = NULL,
+    dataset_bibentry = NULL,
+    dataset_subject = NULL) {
   dots <- list(...)
 
   if (!"rowid" %in% names(dots)) {
@@ -89,23 +99,18 @@ dataset_df <- function(...,
   year <- substr(as.character(sys_time), 1, 4)
 
   if (is.null(dataset_subject)) {
-    dataset_subject <- subject_create(
-      term = "data sets",
-      subjectScheme = "Library of Congress Subject Headings (LCSH)",
-      schemeURI = "https://id.loc.gov/authorities/subjects.html",
-      valueURI = "http://id.loc.gov/authorities/subjects/sh2018002256",
-      classificationCode = NULL,
-      prefix = ""
-    )
+    dataset_subject <- default_subject # See: subject.R
   }
 
   if (is.null(dataset_bibentry)) {
     Title <- "Untitled Dataset"
     Creator <- person("Author", "Unknown")
-    dataset_bibentry <- datacite(Title = Title,
-                                 Creator = Creator,
-                                 Subject = dataset_subject,
-                                 Date = Sys.Date())
+    dataset_bibentry <- datacite(
+      Title = Title,
+      Creator = Creator,
+      Subject = dataset_subject,
+      Date = Sys.Date()
+    )
   }
 
   tmp <- new_dataset(
@@ -118,10 +123,10 @@ dataset_df <- function(...,
   )
 
   dataset_bibentry <- get_bibentry(tmp)
-  if ( dataset_bibentry$year == ":tba" ) dataset_bibentry$year <- year
-  if ( dataset_bibentry$date == ":tba" ) {
+  if (dataset_bibentry$year == ":tba") dataset_bibentry$year <- year
+  if (dataset_bibentry$date == ":tba") {
     dataset_bibentry$date <- as.character(Sys.Date())
-    }
+  }
 
   attr(tmp, "dataset_bibentry") <- dataset_bibentry
   attr(tmp, "subject") <- dataset_subject
@@ -130,13 +135,14 @@ dataset_df <- function(...,
 
 #' @rdname dataset_df
 #' @export
-as_dataset_df <- function(df,
-                          identifier = c(eg = "http://example.com/dataset#"),
-                          var_labels = NULL,
-                          units = NULL,
-                          concepts = NULL,
-                          dataset_bibentry = NULL,
-                          dataset_subject = NULL, ...) {
+as_dataset_df <- function(
+    df,
+    identifier = c(obs = "http://example.com/dataset#obs"),
+    var_labels = NULL,
+    units = NULL,
+    concepts = NULL,
+    dataset_bibentry = NULL,
+    dataset_subject = NULL, ...) {
   dots <- list(...)
 
   if (is.null(dots$dataset_bibentry)) {
@@ -178,9 +184,10 @@ new_dataset <- function(x,
 
   if (add_rowid) {
     tmp <- tibble::rowid_to_column(tmp)
-    prefix <- paste0(names(identifier)[1], ":")
+    prefix <- names(identifier)[1]
     tmp$rowid <- defined(paste0(prefix, tmp$rowid),
-                         namespace = identifier)
+      namespace = identifier
+    )
   }
 
   if (is.null(dataset_bibentry)) {
@@ -200,9 +207,10 @@ new_dataset <- function(x,
 
   tmp
 }
+
 #' @rdname dataset_df
-#' @return \code{is.dataset_df} returns a logical value
-#' (if the object is of class \code{dataset_df}.)
+#' @return `is.dataset_df` returns a logical value
+#' (if the object is of class `dataset_df`.)
 #' @export
 is.dataset_df <- function(x) {
   ifelse("dataset_df" %in% class(x), TRUE, FALSE)
@@ -211,7 +219,6 @@ is.dataset_df <- function(x) {
 #' @rdname dataset_df
 #' @export
 print.dataset_df <- function(x, ...) {
-
   dataset_bibentry <- get_bibentry(x)
   if (is.null(dataset_bibentry)) {
     dataset_bibentry <- set_default_bibentry()
@@ -219,7 +226,7 @@ print.dataset_df <- function(x, ...) {
 
   # Extract fields
   authors <- dataset_bibentry$author
-  year  <- dataset_bibentry$year
+  year <- dataset_bibentry$year
   title <- dataset_bibentry$title
   doi <- dataset_bibentry$identifier
   dataset_date <- dataset_bibentry$Date
@@ -230,30 +237,40 @@ print.dataset_df <- function(x, ...) {
       return(authors[[1]]$family %||% format(authors[[1]]))
     }
 
-    is_institutional <- vapply(authors,
-                               function(a) is.null(a$given) && !is.null(a$family),
-                               logical(1))
+    is_institutional <- vapply(
+      authors,
+      function(a) is.null(a$given) && !is.null(a$family),
+      logical(1)
+    )
     if (all(is_institutional)) {
-      return(paste(vapply(authors,
-                          function(a) a$family, character(1)),
-                   collapse = "-"))
+      return(paste(
+        vapply(
+          authors,
+          function(a) a$family, character(1)
+        ),
+        collapse = "-"
+      ))
     }
 
     if (length(authors) == 2) {
-      return(paste(vapply(authors,
-                          function(a) a$family,
-                          character(1)), collapse = "-"))
+      return(paste(vapply(
+        authors,
+        function(a) a$family,
+        character(1)
+      ), collapse = "-"))
     }
 
     return(paste0(authors[[1]]$family, " et al."))
   }
 
-  apa_header <- sprintf("%s (%s): %s [dataset]",
-                        author_fmt(authors),
-                        year,
-                        title)
+  apa_header <- sprintf(
+    "%s (%s): %s [dataset]",
+    author_fmt(authors),
+    year,
+    title
+  )
 
-  if ( ! is.null(doi) && grepl("doi.org", doi)) {
+  if (!is.null(doi) && grepl("doi.org", doi)) {
     apa_header <- paste0(apa_header, ", ", doi)
   }
 
@@ -282,14 +299,13 @@ tbl_sum.dataset_df <- function(x, ...) {
 
 #' @export
 summary.dataset_df <- function(object, ...) {
-
   dataset_bibentry <- get_bibentry(object)
   if (is.null(dataset_bibentry)) {
     dataset_bibentry <- set_default_bibentry()
   }
   # Extract fields
   authors <- dataset_bibentry$author
-  year  <- dataset_bibentry$year
+  year <- dataset_bibentry$year
   title <- dataset_bibentry$title
   doi <- dataset_bibentry$identifier
 
@@ -299,31 +315,41 @@ summary.dataset_df <- function(object, ...) {
       return(authors[[1]]$family %||% format(authors[[1]]))
     }
 
-    is_institutional <- vapply(authors,
-                               function(a) is.null(a$given) && !is.null(a$family),
-                               logical(1))
+    is_institutional <- vapply(
+      authors,
+      function(a) is.null(a$given) && !is.null(a$family),
+      logical(1)
+    )
     if (all(is_institutional)) {
-      return(paste(vapply(authors,
-                          function(a) a$family, character(1)),
-                   collapse = "-"))
+      return(paste(
+        vapply(
+          authors,
+          function(a) a$family, character(1)
+        ),
+        collapse = "-"
+      ))
     }
 
     if (length(authors) == 2) {
-      return(paste(vapply(authors,
-                          function(a) a$family,
-                          character(1)), collapse = "-"))
+      return(paste(vapply(
+        authors,
+        function(a) a$family,
+        character(1)
+      ), collapse = "-"))
     }
 
     return(paste0(authors[[1]]$family, " et al."))
   }
 
-  apa_header <- sprintf("%s (%s): Summary of %s [dataset]",
-                        author_fmt(authors),
-                        year,
-                        title)
+  apa_header <- sprintf(
+    "%s (%s): Summary of %s [dataset]",
+    author_fmt(authors),
+    year,
+    title
+  )
 
 
-  if ( ! is.null(doi) && grepl("doi.org", doi)) {
+  if (!is.null(doi) && grepl("doi.org", doi)) {
     apa_header <- paste0(apa_header, ", ", doi)
   }
 
